@@ -43,6 +43,70 @@ class RedisStoreIntegrationTest < ::ActionDispatch::IntegrationTest
     end
   end
 
+  test "should set a non-secure cookie by default" do
+    with_test_route_set do
+      https!
+
+      get '/set_session_value'
+      assert_response :success
+
+      cookie = cookies.instance_variable_get('@cookies').first
+
+      assert !cookie.secure?
+    end
+  end
+
+  test "should set a secure cookie when the 'secure' option is set" do
+    with_test_route_set(secure: true) do
+      https!
+
+      get '/set_session_value'
+      assert_response :success
+
+      cookie = cookies.instance_variable_get('@cookies').first
+
+      assert cookie.secure?
+    end
+  end
+
+  test "should set a signed cookie when the 'signed' option is set" do
+    with_test_route_set(signed: true) do
+      https!
+
+      get '/set_session_value'
+      assert_response :success
+
+      cookie = cookies.instance_variable_get('@cookies').first
+
+      assert_includes cookie.raw, '_session_id='
+    end
+  end
+
+
+  test "should set a http-only cookie by default" do
+    with_test_route_set do
+      get '/set_session_value'
+      assert_response :success
+
+      cookie = cookies.instance_variable_get('@cookies').first
+      options = cookie.instance_variable_get('@options')
+
+      assert options.key?('HttpOnly')
+    end
+  end
+
+  test "should set a non-http-only cookie when the 'httponlty' option is set to false" do
+    with_test_route_set(httponly: false) do
+      get '/set_session_value'
+      assert_response :success
+
+      cookie = cookies.instance_variable_get('@cookies').first
+      options = cookie.instance_variable_get('@options')
+
+      assert !options.key?('HttpOnly')
+    end
+  end
+
   test "should not send cookies on write, not read" do
     with_test_route_set do
       get '/get_session_value'
@@ -128,7 +192,7 @@ class RedisStoreIntegrationTest < ::ActionDispatch::IntegrationTest
 
       reset!
 
-      get '/set_session_value', :_session_id => session_id
+      get '/set_session_value', headers: { _session_id: session_id }
       assert_response :success
       assert(cookies['_session_id'] != session_id)
     end
@@ -188,8 +252,17 @@ class RedisStoreIntegrationTest < ::ActionDispatch::IntegrationTest
       def initialize(routes, &blk)
         @routes = routes
         @stack = ActionDispatch::MiddlewareStack.new(&blk).build(@routes)
+        @secret = SecureRandom.hex
+        @key_generator = ActiveSupport::CachingKeyGenerator.new(
+          ActiveSupport::KeyGenerator.new(@secret, iterations: 2)
+        )
       end
       def call(env)
+        env[ActionDispatch::Cookies::GENERATOR_KEY] = @key_generator
+        env[ActionDispatch::Cookies::SIGNED_COOKIE_SALT] = SecureRandom.hex
+        if defined? ActionDispatch::Cookies::COOKIES_ROTATIONS
+          env[ActionDispatch::Cookies::COOKIES_ROTATIONS] = ActiveSupport::Messages::RotationConfiguration.new
+        end
         @stack.call(env)
       end
     end
@@ -199,7 +272,7 @@ class RedisStoreIntegrationTest < ::ActionDispatch::IntegrationTest
       RoutedRackApp.new(routes || ActionDispatch::Routing::RouteSet.new) do |middleware|
         middleware.use ActionDispatch::DebugExceptions
         middleware.use ActionDispatch::Callbacks
-        middleware.use ActionDispatch::ParamsParser
+        # middleware.use ActionDispatch::ParamsParser
         middleware.use ActionDispatch::Cookies
         middleware.use ActionDispatch::Flash
         middleware.use Rack::Head
@@ -211,7 +284,13 @@ class RedisStoreIntegrationTest < ::ActionDispatch::IntegrationTest
     def with_test_route_set(options = {})
       with_routing do |set|
         set.draw do
-          get ':action', :to => ::TestController
+          get :no_session_access,             to: 'test#no_session_access'
+          get :set_session_value,             to: 'test#set_session_value'
+          get :set_session_value_with_expiry, to: 'test#set_session_value_with_expiry'
+          get :set_serialized_session_value,  to: 'test#set_serialized_session_value'
+          get :get_session_value,             to: 'test#get_session_value'
+          get :get_session_id,                to: 'test#get_session_id'
+          get :call_reset_session,            to: 'test#call_reset_session'
         end
         options = { :key => SessionKey }.merge!(options)
         @app = self.class.build_app(set) do |middleware|
